@@ -19,13 +19,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "svgdocumentloadedimpl.moc"
+#include "svgdocumentloadedimpl.h"
 
 // Qt
 #include <QSvgRenderer>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
 
 // Local
 
@@ -65,7 +65,7 @@ Document::LoadingState SvgDocumentLoadedImpl::loadingState() const
 
 void SvgDocumentLoadedImpl::setImage(const QImage&)
 {
-    kWarning() << "Should not be called";
+    qWarning() << "Should not be called";
 }
 
 QByteArray SvgDocumentLoadedImpl::rawData() const
