@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "documentviewcontroller.moc"
+#include "documentviewcontroller.h"
 
 // Local
 #include "abstractdocumentviewadapter.h"
@@ -30,15 +30,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/zoomwidget.h>
 
 // KDE
-#include <KAction>
 #include <KActionCategory>
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 // Qt
 #include <QAction>
-#include <QEvent>
 #include <QHBoxLayout>
+#include <QDebug>
+#include <QAction>
 
 namespace Gwenview
 {
@@ -81,26 +80,26 @@ struct DocumentViewControllerPrivate
     SlideContainer* mToolContainer;
     ToolContainerContent* mToolContainerContent;
 
-    KAction* mZoomToFitAction;
-    KAction* mActualSizeAction;
-    KAction* mZoomInAction;
-    KAction* mZoomOutAction;
-    QList<KAction*> mActions;
+    QAction * mZoomToFitAction;
+    QAction * mActualSizeAction;
+    QAction * mZoomInAction;
+    QAction * mZoomOutAction;
+    QList<QAction *> mActions;
 
     void setupActions()
     {
         KActionCategory* view = new KActionCategory(i18nc("@title actions category - means actions changing smth in interface", "View"), mActionCollection);
 
         mZoomToFitAction = view->addAction("view_zoom_to_fit");
-        mZoomToFitAction->setShortcut(Qt::Key_F);
+        view->collection()->setDefaultShortcut(mZoomToFitAction, Qt::Key_F);
         mZoomToFitAction->setCheckable(true);
         mZoomToFitAction->setChecked(true);
         mZoomToFitAction->setText(i18n("Zoom to Fit"));
-        mZoomToFitAction->setIcon(KIcon("zoom-fit-best"));
+        mZoomToFitAction->setIcon(QIcon::fromTheme("zoom-fit-best"));
         mZoomToFitAction->setIconText(i18nc("@action:button Zoom to fit, shown in status bar, keep it short please", "Fit"));
 
         mActualSizeAction = view->addAction(KStandardAction::ActualSize);
-        mActualSizeAction->setIcon(KIcon("zoom-original"));
+        mActualSizeAction->setIcon(QIcon::fromTheme("zoom-original"));
         mActualSizeAction->setIconText(i18nc("@action:button Zoom to original size, shown in status bar, keep it short please", "100%"));
 
         mZoomInAction = view->addAction(KStandardAction::ZoomIn);
@@ -115,13 +114,10 @@ struct DocumentViewControllerPrivate
             return;
         }
 
-        QObject::connect(mZoomWidget, SIGNAL(zoomChanged(qreal)),
-                         mView, SLOT(setZoom(qreal)));
+        QObject::connect(mZoomWidget, &ZoomWidget::zoomChanged, mView, &DocumentView::setZoom);
 
-        QObject::connect(mView, SIGNAL(minimumZoomChanged(qreal)),
-                         mZoomWidget, SLOT(setMinimumZoom(qreal)));
-        QObject::connect(mView, SIGNAL(zoomChanged(qreal)),
-                         mZoomWidget, SLOT(setZoom(qreal)));
+        QObject::connect(mView, &DocumentView::minimumZoomChanged, mZoomWidget, &ZoomWidget::setMinimumZoom);
+        QObject::connect(mView, &DocumentView::zoomChanged, mZoomWidget, &ZoomWidget::setZoom);
 
         mZoomWidget->setMinimumZoom(mView->minimumZoom());
         mZoomWidget->setZoom(mView->zoom());
@@ -179,12 +175,9 @@ void DocumentViewController::setView(DocumentView* view)
     if (!d->mView) {
         return;
     }
-    connect(d->mView, SIGNAL(adapterChanged()),
-            SLOT(slotAdapterChanged()));
-    connect(d->mView, SIGNAL(zoomToFitChanged(bool)),
-            SLOT(updateZoomToFitActionFromView()));
-    connect(d->mView, SIGNAL(currentToolChanged(AbstractRasterImageViewTool*)),
-            SLOT(updateTool()));
+    connect(d->mView, &DocumentView::adapterChanged, this, &DocumentViewController::slotAdapterChanged);
+    connect(d->mView, &DocumentView::zoomToFitChanged, this, &DocumentViewController::updateZoomToFitActionFromView);
+    connect(d->mView, &DocumentView::currentToolChanged, this, &DocumentViewController::updateTool);
 
     connect(d->mZoomToFitAction, SIGNAL(toggled(bool)),
             d->mView, SLOT(setZoomToFit(bool)));
@@ -252,9 +245,7 @@ void DocumentViewController::updateTool()
     if (tool && tool->widget()) {
         // Use a QueuedConnection to ensure the size of the view has been
         // updated by the time the slot is called.
-        connect(d->mToolContainer, SIGNAL(slidedIn()),
-            tool, SLOT(onWidgetSlidedIn()),
-            Qt::QueuedConnection);
+        connect(d->mToolContainer, &SlideContainer::slidedIn, tool, &AbstractRasterImageViewTool::onWidgetSlidedIn, Qt::QueuedConnection);
         d->mToolContainerContent->setToolWidget(tool->widget());
         d->mToolContainer->slideIn();
     } else {
